@@ -1,3 +1,6 @@
+# Copyright New York University and the in-toto contributors
+# SPDX-License-Identifier: Apache-2.0
+
 """
 <Program Name>
   runlib.py
@@ -24,7 +27,6 @@
     - Return Metablock containing a Link object which can be can be signed
       and stored to disk
 """
-import six
 import glob
 import logging
 import os
@@ -213,8 +215,8 @@ def record_artifacts_as_dict(artifacts, exclude_patterns=None,
       os.chdir(base_path)
 
     except Exception as e:
-      six.raise_from(ValueError("Could not use '{}' as base path: '{}'".format(
-          base_path, e)), e)
+      raise ValueError("Could not use '{}' as base path: '{}'".format(
+          base_path, e)) from  e
 
   # Normalize passed paths
   norm_artifacts = []
